<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg_BG" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <source>Themes or indent schemes not found.
Check installation.</source>
        <translation type="obsolete">Не са намерени теми или схеми за подреждане.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="105"/>
        <source>Initialization error</source>
        <translation>Грешка при инициализация</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="106"/>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation>Не могат да бъдат открити синтактични определения.
Проверете инсталацията.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="182"/>
        <source>Always at your service</source>
        <translation>Винаги на вашите услуги</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="209"/>
        <source>Select one or more files to open</source>
        <translation>Изберете един или повече файлове за отваряне</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="246"/>
        <source>Select destination directory</source>
        <translation>Изберете целева папка</translation>
    </message>
    <message>
        <source>Tags file error</source>
        <translation type="obsolete">Грешка във файл с маркери</translation>
    </message>
    <message>
        <source>Could not read tags information in &quot;%1&quot;</source>
        <translation type="obsolete">Не може да бъде прочетена информация за маркери в &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="878"/>
        <location filename="mainwindow.cpp" line="909"/>
        <source>Output error</source>
        <translation>Изходна грешка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="878"/>
        <source>Output directory does not exist!</source>
        <translation>Изходната папка не съществува!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="909"/>
        <source>You must define a style output file!</source>
        <translation>Трябва да определите файл със стилови описания за изход!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="941"/>
        <source>Processing %1 (%2/%3)</source>
        <translation>Обработка на %1 (%2/%3)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="947"/>
        <source>Language definition error</source>
        <translation>Грешка в описанието на езика</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="948"/>
        <source>Invalid regular expression in %1:
%2</source>
        <translation>Недействителен регулярен израз в %1: %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="952"/>
        <source>Unknown syntax</source>
        <translation>Непознат синтаксис</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="952"/>
        <source>Could not convert %1</source>
        <translation>Невъзможност за превръщане на %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="955"/>
        <source>Lua error</source>
        <translation>Lua грешка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="955"/>
        <source>Could not convert %1:
Lua Syntax error: %2</source>
        <translation>Невъзможност за превръщане на %1:\nLua синтактична грешка: %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1028"/>
        <source>Converted %1 files in %2 ms</source>
        <translation>%1 файла превърнати за %2 мс</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1126"/>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation>Превръщането на &quot;%1&quot; не е възможно.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1126"/>
        <location filename="mainwindow.cpp" line="1244"/>
        <location filename="mainwindow.cpp" line="1269"/>
        <source>clipboard data</source>
        <translation>данни от системен буфер</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1193"/>
        <source>%1 options</source>
        <translation>%1 настройки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1230"/>
        <location filename="mainwindow.cpp" line="1236"/>
        <source>(user script)</source>
        <translation>(потребителски скрипт)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1243"/>
        <source>Preview (%1):</source>
        <translation>Преглед (%1):</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1246"/>
        <source>Current syntax: %1 %2</source>
        <translation>Текущ синтаксис: %1 %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1247"/>
        <source>Current theme: %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current syntax: %1</source>
        <translation type="vanished">Текущ синтаксис: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1269"/>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation>Преглед на &quot;%1&quot; не е възможен.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1520"/>
        <source>Some plug-in effects may not be visible in the preview.</source>
        <translation>Някои ефекти от модули може да не са видими в прегледа.</translation>
    </message>
    <message>
        <source>Choose a ctags file</source>
        <translation type="obsolete">Избор на ctags файл</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1306"/>
        <location filename="mainwindow.cpp" line="1310"/>
        <location filename="mainwindow.cpp" line="1314"/>
        <location filename="mainwindow.cpp" line="1319"/>
        <source>Choose a style include file</source>
        <translation>Изберете файл със стилови описания за включване</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1324"/>
        <source>About providing translations</source>
        <translation>За предоставянето на преводи</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1325"/>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation>Този ГПИ е разработен с използването на Qt инструментариум и преводи могат да бъдат предоставяни с използването на инструментите Qt Linguist и lrelease.
Файла highlight.ts за Linguist се намира в src/gui-qt подпапката.
Файла qm създаден с lrelease трябва да бъде съхранен в gui-files/l10n.

Моля, пишете на as (at) andre-simon (dot) de ако имате проблeми при превода или ако сте завършили или обновили превод.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1383"/>
        <source>Select one or more plug-ins</source>
        <translation>Изберете един или повече модули</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1394"/>
        <source>Select one or more syntax or theme scripts</source>
        <translation>Изберете един или повече синтактични или тематични скриптове</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1454"/>
        <source>Choose a plug-in input file</source>
        <translation>Изберете входен файл с модул</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Choose the source code files you want to convert.</source>
        <translation>Избор на изходните файлове, които желаете да превърнете.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <source>Choose input files</source>
        <translation>Избор на входни файлове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="212"/>
        <source>List of input files.</source>
        <translation>Списък с входни файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Remove the selected input files.</source>
        <translation>Премахване на избраните входни файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.ui" line="553"/>
        <location filename="mainwindow.ui" line="689"/>
        <source>Clear selection</source>
        <translation>Премахване на избраните</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Remove all input files.</source>
        <translation>Премахване на всички входни файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="249"/>
        <location filename="mainwindow.ui" line="563"/>
        <location filename="mainwindow.ui" line="699"/>
        <source>Clear all</source>
        <translation>Премахване на всички</translation>
    </message>
    <message>
        <source>Output destination</source>
        <translation type="obsolete">Цел на изхода</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="288"/>
        <source>Output directory</source>
        <translation>Изходяща папка</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Select the output directory.</source>
        <translation>Избора на изходящата папка.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="310"/>
        <location filename="mainwindow.ui" line="640"/>
        <location filename="mainwindow.ui" line="1286"/>
        <location filename="mainwindow.ui" line="1555"/>
        <location filename="mainwindow.ui" line="1663"/>
        <location filename="mainwindow.ui" line="1958"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Save output in the input file directories.</source>
        <translation>Записване на изхода в папките на входните файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Write to source directories</source>
        <translation>Писане във входни папки</translation>
    </message>
    <message>
        <source>Output options</source>
        <translation type="obsolete">Опции за изход</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="756"/>
        <source>General</source>
        <translation>Общи</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="776"/>
        <source>Output for&amp;mat:</source>
        <oldsource>Output format:</oldsource>
        <translation>Изходен фор&amp;мат:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>Choose an output format.</source>
        <translation>Избор на изходен формат.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="802"/>
        <source>HTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <source>XHTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="812"/>
        <source>LaTeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="817"/>
        <source>TeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="822"/>
        <source>RTF</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>ODT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="832"/>
        <source>SVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="856"/>
        <source>Add line numbers to the output.</source>
        <translation>Добавяне на номера на редове в изхода.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="859"/>
        <source>Add line numbers</source>
        <translation>Добавяне на номера на редове</translation>
    </message>
    <message>
        <source>Set line numbering start</source>
        <translation type="vanished">Задаване на начало на номерацията</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="898"/>
        <source>Select the line number width.</source>
        <translation>Избора на дължина на номера на реда.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="919"/>
        <source>Fill leading space of line numbers with zeroes.</source>
        <translation>Подпълване на номерата на редове с водещи нули.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="922"/>
        <source>Pad with zeroes</source>
        <translation>Подпълване с нули</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Generate output without document header and footer.</source>
        <translation>Създаване на изход без горен и долен колонтитул.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="938"/>
        <source>Omit header and footer</source>
        <translation>Пропускане на горен и долен колонтитул</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <source>Output any plug-in text injections even if document header and footer is omitted.</source>
        <translation>Извеждане на всеки текст вмъкнат от модули дори ако горен и долен колонтитул са пропуснати.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="948"/>
        <source>Keep Plug-In injections</source>
        <translation>Запазване на текста вмъкнат от модули</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="955"/>
        <source>Test if input data is not binary.
Removes Unicode BOM mark.</source>
        <translation>Проверява дали входните данни не са двоични.
Премахва Unicode BOM.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="959"/>
        <source>Validate input data</source>
        <translation>Проверка на входни данни</translation>
    </message>
    <message>
        <source>Set the output file ancoding.</source>
        <translation type="vanished">Задаване кодирането на изходния файл.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1796"/>
        <source>I&amp;mage width:</source>
        <translation>Дължина на &amp;изображението:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1844"/>
        <source>Height:</source>
        <oldsource>Image height:</oldsource>
        <translation>Височина:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2103"/>
        <source>Reformat and indent your code.
This feature is enabled for C, C++, C# and Java code.</source>
        <translation>Преформатиране и подреждане на кода.
Тази възможност е налична за C, C++, C# и Java код.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2431"/>
        <source>&amp;Plug-Ins</source>
        <translation>&amp;Модули</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation type="obsolete">Кодиране:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="988"/>
        <source>Select or define the encoding.
The result has to match the input file encoding.</source>
        <translation>Избор или определяне на кодиране.
Резултата трябва да съвпада с кодирането на входния файл.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="999"/>
        <source>ISO-8859-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1004"/>
        <source>ISO-8859-2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1009"/>
        <source>ISO-8859-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1014"/>
        <source>ISO-8859-4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1019"/>
        <source>ISO-8859-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1024"/>
        <source>ISO-8859-6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1029"/>
        <source>ISO-8859-7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1034"/>
        <source>ISO-8859-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1039"/>
        <source>ISO-8859-9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1044"/>
        <source>ISO-8859-10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1049"/>
        <source>ISO-8859-11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1054"/>
        <source>ISO-8859-12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1059"/>
        <source>ISO-8859-13</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1064"/>
        <source>ISO-8859-14</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1069"/>
        <source>ISO-8859-15</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1074"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1098"/>
        <source>Output specific</source>
        <translation>Особености на изхода</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1395"/>
        <source>Add HTML MIME Type when copying code to the clipboard</source>
        <translation>Добавяне на HTML MIME-Type при копиране на код в системния буфер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1398"/>
        <source>Copy with MIME type</source>
        <translation>Копиране с MIME-Type</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1436"/>
        <source>Adapt output for the Babel package</source>
        <translation>Приспособяване на изхода за пакета Babel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1446"/>
        <source>Adapt output for the Beamer package</source>
        <translation>Приспособяване на изхода за пакета Beamer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1449"/>
        <source>Add Beamer compatibility</source>
        <translation>Добавяне на Beamer съвместимост</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1700"/>
        <source>Set page color attribute to background color.</source>
        <translation>Задаване на атрибут за цвят на страница към цвят на фона.</translation>
    </message>
    <message>
        <source>HTML options</source>
        <translation type="obsolete">Опции за HTML</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="obsolete">Стил</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1147"/>
        <location filename="mainwindow.ui" line="1473"/>
        <location filename="mainwindow.ui" line="1581"/>
        <location filename="mainwindow.ui" line="1876"/>
        <source>Include the style information in each output file.</source>
        <translation>Включване на стилова информация във всеки изходен файл.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1150"/>
        <location filename="mainwindow.ui" line="1879"/>
        <source>Embed style (CSS)</source>
        <translation>Вграден стил (CSS)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1163"/>
        <source>Add CSS information to each tag (do not use CSS class definitions).</source>
        <translation>Добавяне на CSS информация към всеки маркер (да не се използват CSS клас определения).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1166"/>
        <source>Inline CSS</source>
        <translation>Вложен CSS</translation>
    </message>
    <message>
        <source>Style file:</source>
        <translation type="obsolete">Файл със стилове:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1226"/>
        <location filename="mainwindow.ui" line="1609"/>
        <location filename="mainwindow.ui" line="1904"/>
        <source>Name of the referenced style file.</source>
        <translation>Име на използвания файл със стилове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1229"/>
        <location filename="mainwindow.ui" line="1907"/>
        <source>highlight.css</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include file:</source>
        <translation type="obsolete">Файл със стилове за включване:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1270"/>
        <location filename="mainwindow.ui" line="1942"/>
        <source>Path of the CSS include file.</source>
        <translation>Път към CSS файла за включване.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1283"/>
        <source>Select a CSS include file.</source>
        <translation>Избор на CSS файл за включване.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1180"/>
        <source>CSS class prefix:</source>
        <translation>Представка за CSS клас:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1193"/>
        <source>Add a CSS class name prefix to avoid namespace clashes.</source>
        <translation>Добавяне на представка към имена на CSS класове за избягване на колизии с имена.</translation>
    </message>
    <message>
        <source>Tags and index files</source>
        <translation type="obsolete">Маркери и индекс файлове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1368"/>
        <source>Generate an index file with hyperlinks to all outputted files.</source>
        <translation>Създаване на индекс файл с връзки към всички изходни файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1371"/>
        <source>Generate index file</source>
        <translation>Създаване на индекс файл</translation>
    </message>
    <message>
        <source>Read a ctags file and add the included metainformation as tooltips.
See ctags.sf.net for details.</source>
        <translation type="obsolete">Четене на ctags файл и добавяне на включената метаинформация като подсказки.
Вижте ctags.sf.net за подробности.</translation>
    </message>
    <message>
        <source>Ctags file:</source>
        <translation type="obsolete">Ctags файл:</translation>
    </message>
    <message>
        <source>Path of the ctags file.</source>
        <translation type="obsolete">Път към ctags файл.</translation>
    </message>
    <message>
        <source>Choose a ctags file.</source>
        <translation type="obsolete">Избор на ctags файл.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1312"/>
        <source>Misc</source>
        <translation>Разни</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1331"/>
        <source>Add an achor to each line.</source>
        <translation>Добавяне на котва към всеки ред.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1334"/>
        <source>Add line anchors</source>
        <translation>Добавяне на котва към ред</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1341"/>
        <source>Add the filename as prefix to the anchors.</source>
        <translation>Добавяне името на файла като представка към името на котвата.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1344"/>
        <source>Include file name in anchor</source>
        <translation>Включване на името на файла в котва</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1351"/>
        <source>Output the lines within an ordered list.</source>
        <translation>Извеждане на редовете в подреден списък.</translation>
    </message>
    <message>
        <source>Ordered list</source>
        <translation type="obsolete">Подреден списък</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1378"/>
        <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
        <translation>Добавяне на &amp;lt;pre&amp;gt; маркери към изхода, когато флага &quot;Пропускане на горен и долен колонтитул&quot; е избран.</translation>
    </message>
    <message>
        <source>Enclose in &lt;pre&gt;</source>
        <translation type="obsolete">Ограждане с &amp;lt;pre&amp;gt;</translation>
    </message>
    <message>
        <source>LaTeX options</source>
        <translation type="obsolete">LaTeX опции</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1426"/>
        <source>Replace quotes by dq sequences.</source>
        <translation>Заместване на кавички с dq последователности.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1429"/>
        <source>Escape quotes</source>
        <translation>Заместване на кавички</translation>
    </message>
    <message>
        <source>Make output Babel compatible.</source>
        <translation type="vanished">Прави изхода Babel съвместим.</translation>
    </message>
    <message>
        <source>Babel compatibility</source>
        <translation type="obsolete">Babel съвместим</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1456"/>
        <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
        <translation>Заменя символите по подразбиране (скоби, тилда) с правилни  .</translation>
    </message>
    <message>
        <source>Pretty symbols</source>
        <translation type="obsolete">Символи за хубав печат</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1476"/>
        <source>Embed style (defs)</source>
        <translation>Вграждане на стилови определения</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1501"/>
        <source>Name of the referenced  style file.</source>
        <translation>Име на използвания файл със стилове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1504"/>
        <location filename="mainwindow.ui" line="1612"/>
        <source>highlight.sty</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include:</source>
        <translation type="obsolete">Включване на стил:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="981"/>
        <source>Set encoding:</source>
        <translation>Кодиране:</translation>
    </message>
    <message>
        <source>Read ctags file:</source>
        <translation type="obsolete">Четене на ctags файл:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1354"/>
        <source>Output as ordered list</source>
        <translation>Извеждане като подреден списък</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1381"/>
        <source>Enclose in pre tags</source>
        <translation>Заграждане с pre маркери</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1439"/>
        <source>Add Babel compatibility</source>
        <translation>Добавяне на Babel съвместимост</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1459"/>
        <source>Add pretty symbols</source>
        <translation>Добавяне на символи за хубав печат</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1207"/>
        <location filename="mainwindow.ui" line="1485"/>
        <location filename="mainwindow.ui" line="1593"/>
        <location filename="mainwindow.ui" line="1888"/>
        <source>Stylesheet file:</source>
        <translation>Файл със стилови описания:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="273"/>
        <source>Output destination:</source>
        <translation>Изходяща папка:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="329"/>
        <source>Browse output directory</source>
        <translation>Преглед на изходяща папка</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="481"/>
        <source>Paste code from clipboard and copy the output back in one step</source>
        <translation>Поставяне на код от системния буфер и копиране на изхода обратно в една стъпка</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="487"/>
        <source>Paste, Convert and Copy</source>
        <translation>Поставяне, превръщане и копиране</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="654"/>
        <source>Scripts</source>
        <translation>Скриптове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="660"/>
        <source>Choose a custom syntax or theme script.</source>
        <translation>Избор на друг синтактичен или тематичен скрипт.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="663"/>
        <source>Add custom script to pool</source>
        <translation>Добавяне на потребителски скрипт към склада</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>You can check one file of each type (syntax and theme) to override the default behaviour. If checked, the scripts will be watched for changes.</source>
        <oldsource>You can check one file of each type (syntax and theme) to override the default behaviour.</oldsource>
        <translation>Можете да изберете по един файл от всеки тип (синтактичен и тематичен), за да промените настройките по подразбиране. Ако са отметнати, скриптовете ще бъдат наблюдавани за промени.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="686"/>
        <source>Remove the selected scripts.</source>
        <translation>Премахване на избраните скриптове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="696"/>
        <source>Remove all scripts.</source>
        <translation>Премахване на всички скриптове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="714"/>
        <source>Shows decription of a selected script.</source>
        <translation>Показва описание на избрания скрипт.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Script description</source>
        <translation>Описание на скрипт</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="879"/>
        <source>Set line numbering start.</source>
        <translation>Задаване на начало на номерацията.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="966"/>
        <source>Generate output without version information comment.</source>
        <translation>Създаване на изход без коментар с информация за версията.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="969"/>
        <source>Omit version info comment</source>
        <translation>Без коментар с информация за версията</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="978"/>
        <source>Set the output file encoding.</source>
        <translation>Задаване на кодирането на изходния файл.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1240"/>
        <location filename="mainwindow.ui" line="1515"/>
        <location filename="mainwindow.ui" line="1623"/>
        <location filename="mainwindow.ui" line="1918"/>
        <source>Stylesheet include file:</source>
        <translation>Файл със стилови описания за включване:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1324"/>
        <source>Line numbering options:</source>
        <translation>Настройки за номерация на редове:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <source>Highlight</source>
        <translation>Синтактично оцветяване</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="174"/>
        <source>Files</source>
        <translation>Файлове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <source>Paste clipboard content into the preview window.</source>
        <translation>Поставяне на съдържанието на системния буфер в прозореца за преглед.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="438"/>
        <source>Paste from clipboard (%1)</source>
        <oldsource>Paste from clipboard</oldsource>
        <translation>Поставяне от системен буфер (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="455"/>
        <source>Copy highlighted code into the clipboard.</source>
        <translation>Копиране на оцветения код в системния буфер.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Copy preview to clipboard (%1)</source>
        <oldsource>Copy preview to clipboard</oldsource>
        <translation>Копиране на преглед в системен буфер (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <source>Select syntax:</source>
        <translation>Избор на синтаксис:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="426"/>
        <source>Select the correct syntax of the code snippet.</source>
        <translation>Избор на правилния синтаксис за парчето код.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="512"/>
        <source>Plug-ins</source>
        <translation>Модули</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="521"/>
        <source>Add plug-in to pool</source>
        <translation>Добавяне на модул към склада</translation>
    </message>
    <message>
        <source>List of plug-ins.</source>
        <translation type="obsolete">Списък с модули.</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Remove the selected plug-ins.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Премахване на избраните модули.</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Remove all plug-ins.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Премахване на всички модули</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Use the selected plugin.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">Използване на избраните модули.</translation>
    </message>
    <message>
        <source>Enable selected plug-in script</source>
        <translation type="obsolete">Разрешаване на избраните модули</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="837"/>
        <source>BBCode</source>
        <translation>BBCode</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1139"/>
        <source>Stylesheets</source>
        <translation>Стилови описания</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation type="vanished">Включване:</translation>
    </message>
    <message>
        <source>Index/ctags</source>
        <translation type="obsolete">Индекс/ctags</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1539"/>
        <location filename="mainwindow.ui" line="1647"/>
        <source>Path of the style include file.</source>
        <translation>Път към файла със стилови описания за включване.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1552"/>
        <location filename="mainwindow.ui" line="1660"/>
        <location filename="mainwindow.ui" line="1955"/>
        <source>Select a style include file.</source>
        <translation>Избор на файл със стилови описания за включване.</translation>
    </message>
    <message>
        <source>TeX options</source>
        <translation type="obsolete">TeX опции</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1584"/>
        <source>Embed style (macros)</source>
        <translation>Вграждане на стил (макроси)</translation>
    </message>
    <message>
        <source>RTF options</source>
        <translation type="obsolete">RTF опции</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1689"/>
        <source>Add character stylesheets with formatting information.
You can select the stylesheets in your word processor to reformat additional text.</source>
        <translation>Добавяне на стилови описания с информация за форматиране на знаци.
Можете да изберете стиловите описания във вашия текстов редактор, за да преформатирате допълнително текста.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1693"/>
        <source>Add character styles</source>
        <translation>Добавяне на стилове за знаци</translation>
    </message>
    <message>
        <source>Set page color attribute to background color</source>
        <translation type="vanished">Задаване на атрибут за цвят на страница към цвят на фона</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1703"/>
        <source>Set page color</source>
        <translation>Задаване на цвят на страница</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1712"/>
        <source>Page size:</source>
        <translation>Размер на страница:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1725"/>
        <source>Select a page size.</source>
        <translation>Избор на размер на страница.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1732"/>
        <source>A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1737"/>
        <source>A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1742"/>
        <source>A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1747"/>
        <source>B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1752"/>
        <source>B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1757"/>
        <source>B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1762"/>
        <source>Letter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1767"/>
        <source>Legal</source>
        <translation></translation>
    </message>
    <message>
        <source>SVG options</source>
        <translation type="obsolete">SVG опции</translation>
    </message>
    <message>
        <source>Image size:</source>
        <translation type="vanished">Размер на изображението:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="vanished">Широчина:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1824"/>
        <source>Enter the SVG width (may contain units).</source>
        <translation>Въвеждане широчина на SVG (може да съдържа единици).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1860"/>
        <source>Enter the SVG height (may contain units).</source>
        <translation>Въвеждане на височина на SVG (може да съдържа единици).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1984"/>
        <source>No options defined.</source>
        <translation>Няма опции.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2009"/>
        <source>Formatting</source>
        <translation>Форматиране</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2032"/>
        <source>Color theme:</source>
        <translation>Цветова тема:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2064"/>
        <source>Toggle classic theme or Base16 theme selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2067"/>
        <source>Base16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2086"/>
        <source>Select a colour theme.</source>
        <translation>Избор на цветова тема.</translation>
    </message>
    <message>
        <source>Reformat and indent your code.
This feature is enabled tor C, C++, C# and Java code.</source>
        <translation type="vanished">Преформатиране и подреждане на кода.
Тази възможност е налична за C, C++, C# и Java код.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2107"/>
        <source>Reformat:</source>
        <translation>Преформатиране:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2126"/>
        <source>Choose a formatting scheme.</source>
        <translation>Избор на схема за форматиране.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2140"/>
        <source>Change the keyword case.</source>
        <translation>Промяна на регистъра на ключовите думи.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2143"/>
        <source>Keyword case:</source>
        <translation>Регистър за ключови думи:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2162"/>
        <source>Select a keyword case.</source>
        <translation>Избор на регистър за ключови думи.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2169"/>
        <source>UPPER</source>
        <translation>ГОРЕН</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2174"/>
        <source>lower</source>
        <translation>долен</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2179"/>
        <source>Capitalize</source>
        <translation>Изречение</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2197"/>
        <source>Tab width:</source>
        <translation>Дължина на табулатор:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2213"/>
        <source>Enter the number of spaces which replace a tab.
Set the width to 0 to keep tabs.</source>
        <translation>Въвеждане на броя интервали заместващи табулатор.
Въведете 0 за запазване на табулатори.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2228"/>
        <source>Enable line wrapping.</source>
        <translation>Разрешаване на пренасяне на редове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2231"/>
        <source>Line wrapping</source>
        <translation>Пренасяне на редове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2244"/>
        <source>Enter the maximum line length.</source>
        <translation>Въвеждане на максимална дължина на ред.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2263"/>
        <source>Indent statements and function parameters after wrapping.</source>
        <translation>Подреждане на изрази и параметри на функции след пренасяне.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2266"/>
        <source>Intelligent wrapping</source>
        <translation>Интелигентно пренасяне</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2287"/>
        <source>Font na&amp;me:</source>
        <oldsource>Font name:</oldsource>
        <translation>Име на &amp;шрифт:</translation>
    </message>
    <message>
        <source>Select or enter the font name.</source>
        <translation type="obsolete">Избор или въвеждане на име на шрифт.</translation>
    </message>
    <message>
        <source>Font size:</source>
        <translation type="vanished">Размер на шрифт:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2342"/>
        <source>Enter the font size.</source>
        <translation>Въвеждане на размер на шрифта.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2415"/>
        <source>&amp;Visit andre-simon.de</source>
        <oldsource>Visit andre-simon.de</oldsource>
        <translation>&amp;Посещаване на andre-simon.de</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2426"/>
        <source>&amp;Dock floating panels</source>
        <translation>&amp;Закачане на плаващи панели</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>Preview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Visit website</source>
        <translation type="obsolete">Посещаване на сайта</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="383"/>
        <source>Start the conversion of your input files.</source>
        <translation>Започва превръщането на входните файлове.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="386"/>
        <source>Convert files</source>
        <translation>Превръщане на файлове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="396"/>
        <source>Copy highlighted code of the seleted file into the clipboard.</source>
        <translation>Копиране на оцветения код на избрания файл в системния буфер.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <source>Clipboard</source>
        <translation>Системен буфер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="399"/>
        <source>Copy file to clipboard</source>
        <translation>Копиране на файл към системен буфер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="518"/>
        <source>Choose a plug-in script.</source>
        <translation>Избор на скрипт на модул.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="532"/>
        <source>List of plug-ins. Toggle checkbox to enable the scripts. The preview window may not display all plug-in effects.</source>
        <oldsource>List of plug-ins. Toggle checkbox to enable the scripts.</oldsource>
        <translation>Списък на модули. Щракнете върху отметката, за да разрешите скриптовете. Прозореца за преглед може да не покаже всички ефекти от модули.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="550"/>
        <source>Remove the selected plug-ins.</source>
        <translation>Премахване на избраните модули.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>Remove all plug-ins.</source>
        <translation>Премахване на всички модули.</translation>
    </message>
    <message>
        <source>Use the selected plugin.</source>
        <translation type="obsolete">Използване на избрания модул.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>Output progress:</source>
        <translation>Напредък:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>П&amp;омощ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <source>Wi&amp;ndows</source>
        <oldsource>&amp;Windows</oldsource>
        <translation>&amp;Прозорци</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="129"/>
        <source>H&amp;ighlighting options</source>
        <oldsource>Highlighting options</oldsource>
        <translation>Опции за о&amp;цветяване</translation>
    </message>
    <message>
        <source>You can apply system shortcuts for copy and paste.</source>
        <translation type="vanished">Можете да използвате системните клавишни комбинации за копиране и поставяне.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <location filename="mainwindow.ui" line="708"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="584"/>
        <source>Shows decription of a selected plug-in script.</source>
        <translation>Показва описание на избрания модул.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="587"/>
        <source>Plug-In description</source>
        <translation>Описание на модула</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="615"/>
        <source>Plug-in parameter</source>
        <oldsource>Plug-in input file</oldsource>
        <translation>Параметър на модула</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Optional plug-in parameter, this may be a path to a plug-in input file</source>
        <oldsource>Optional path to a plug-in input file</oldsource>
        <translation>Незадължителен параметър на модула, който може да бъде път към файл на модул</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="637"/>
        <source>Select the plug-in input file.</source>
        <translation>Избор на входен файл на модула.</translation>
    </message>
    <message>
        <source>Replace spaces by nbsp entities.</source>
        <oldsource>Replace spaces by &amp;nbsp; entities.</oldsource>
        <translation type="obsolete">Замяна на интервали с &amp;nbsp; кодове.</translation>
    </message>
    <message>
        <source>Use non breaking spaces</source>
        <translation type="obsolete">Използване на твърди интервали</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2273"/>
        <source>Do not add line numbering to lines which were automatically wrapped.</source>
        <translation>Без номериране на редове, които са били автоматично пренесени.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2276"/>
        <source>Omit line numbers of wrapped lines</source>
        <translation>Пропускане на номер за пренесени редове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2308"/>
        <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
        <translation>Избор или въвеждане на име на шрифт. HTML поддържа списък с шрифтове, разделени със запетая.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2320"/>
        <source>Font si&amp;ze:</source>
        <translation>Размер на &amp;шрифта:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2357"/>
        <source>&amp;Open files</source>
        <translation>&amp;Отваряне на файлове</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2362"/>
        <source>&amp;Exit</source>
        <translation>&amp;Изход</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2367"/>
        <source>&amp;Load</source>
        <translation>&amp;Зареждане</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2372"/>
        <source>&amp;Save</source>
        <translation>&amp;Запазване</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2377"/>
        <source>Load &amp;default project</source>
        <translation>Зареждане на проект по &amp;подразбиране</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2382"/>
        <source>&amp;Readme</source>
        <oldsource>Readme</oldsource>
        <translation>Файл Про&amp;чети ме</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2387"/>
        <source>&amp;Tips</source>
        <translation>&amp;Съвети</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2395"/>
        <source>&amp;Changelog</source>
        <translation>&amp;Журнал на промените</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2400"/>
        <source>&amp;License</source>
        <translation>&amp;Лиценз</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2405"/>
        <source>&amp;About Highlight</source>
        <translation>Относно &amp;Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2410"/>
        <source>A&amp;bout translations</source>
        <oldsource>About &amp;translations</oldsource>
        <translation>Относно п&amp;реводите</translation>
    </message>
</context>
<context>
    <name>ShowTextFile</name>
    <message>
        <location filename="showtextfile.ui" line="17"/>
        <source>Show text</source>
        <translation>Показване на текст</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="37"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="69"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>io_report</name>
    <message>
        <location filename="io_report.ui" line="14"/>
        <source>Error summary</source>
        <translation>Резюме на грешките</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="24"/>
        <source>Input errors:</source>
        <translation>Входни грешки:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="34"/>
        <source>Remove files above from input file list</source>
        <translation>Премахване на файлове отгоре от списъка с входящи файлове</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="48"/>
        <source>Output errors:</source>
        <translation>Изходни грешки:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="65"/>
        <source>Reformatting not possible:</source>
        <translation>Преформатирането не е възможно:</translation>
    </message>
</context>
<context>
    <name>syntax_chooser</name>
    <message>
        <location filename="syntax_chooser.ui" line="14"/>
        <source>Syntax selection</source>
        <translation>Избор на синтаксис</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="32"/>
        <source>Select correct syntax</source>
        <translation>Избор на правилен синтаксис</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="50"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="74"/>
        <source>These entries are configured in filetypes.conf.</source>
        <translation>Елементите на списъка са зададени в filetypes.conf.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="81"/>
        <source>The selection will be remembered for this session.</source>
        <translation>Избора ще бъде запомнен за тази сесия.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="84"/>
        <source>Remember selection</source>
        <translation>Запомняне на избора</translation>
    </message>
    <message>
        <location filename="syntax_chooser.cpp" line="57"/>
        <source>The file extension %1 is assigned to multiple syntax definitions.
Select the correct one:</source>
        <translation>Файловото разширение %1 е свързано с няколко синтактични описания.
Изберете правилното:</translation>
    </message>
</context>
</TS>
